clear
set more off
capture log close


log using ${log}Table2.log, replace

*****************************************
***UPPER PART OF THE TABLE***************
*****************************************

***open the worker-level datasets to calculate the share variables needed in Table 2
use ${data}finalsample_dario_pt.dta, clear

***Keep only firms with 95% or more of hours reported
keep if fullsize5==1

***Gen Occupation for Merge with PIACC
gen DISCO=substr(occu09,1,4)
gen DISCO3=substr(occu09,1,3)
gen DISCO2=substr(occu09,1,3)
sort DISCO

***Merge with PIACC
merge m:1 DISCO using ${data}coop_piacc1b.dta
drop if _merge==2
drop _m

***Take the median value in each firm-year- Replace with mean when median is missing
foreach j in F_Q01b_median F_Q02a_median {
bysort cvrnr year: egen  f`j'=median(`j')
bysort cvrnr year: egen  fa`j'=mean(`j')
replace f`j'=fa`j' if f`j'==.
}
rename fF_Q02a_median timecooperating
rename fF_Q01b_median sharinginfo

***Define skill groups
gen skill_inddef1=personeffect+xb
forvalues i=10(10)90 {
bys year: egen bound`i'=pctile(skill_inddef1), p(`i')
}

gen skill_def2=.
replace skill_def2=1 if skill_inddef1<=bound10
replace skill_def2=2 if skill_inddef1>bound10 & skill_inddef1<=bound20
replace skill_def2=3 if skill_inddef1>bound20 & skill_inddef1<=bound30
replace skill_def2=4 if skill_inddef1>bound30 & skill_inddef1<=bound40
replace skill_def2=5 if skill_inddef1>bound40 & skill_inddef1<=bound50
replace skill_def2=6 if skill_inddef1>bound50 & skill_inddef1<=bound60
replace skill_def2=7 if skill_inddef1>bound60 & skill_inddef1<=bound70
replace skill_def2=8 if skill_inddef1>bound70 & skill_inddef1<=bound80
replace skill_def2=9 if skill_inddef1>bound80 & skill_inddef1<=bound90
replace skill_def2=10 if skill_inddef1>bound90

***Standard deviation of hours btw skill groups (i.e. hours constraints measure)
preserve 
bysort cvrnr skill_def2 year: egen mean_hours2=mean(timtot)
bysort cvrnr skill_def2 year: keep if _n==1 
bysort cvrnr year: egen sd2=sd(mean_hours2)
bysort cvrnr year: keep if _n==1
keep cvrnr year sd2
sort cvrnr year
save ${temp}sd_def2, replace
restore
merge m:1 cvrnr year using ${temp}sd_def2
drop _merge
collapse sd2 ind_3 , by(cvrnr year) 


***merge with the share of workers employed in inflexible jobs
sort cvrnr year
merge cvrnr year using ${data}inflex_job.dta, keep(high_constr4)
gen merge_inf=(_merge==3)
drop _merge
rename high_constr4 inflexible


***merge with the share of workers employed in secondary jobs
sort cvrnr year
merge cvrnr year using ${data}sec_job.dta, keep(high_constr4)
gen merge_sec=(_merge==3)
drop _merge
rename high_constr4 sec_job


***Column 1
foreach i in sec_job inflexible sd2  {

egen `i'std=std(`i')
local labelx: variable label `i'
replace `i'=`i'std
label var `i' "`labelx'"

}

foreach j in inflexible sec_job  {
reg  sd2 `j' if merge_inf==1 & merge_sec==1  , cluster(cvrnr)
estimates store est_`j'
}

esttab  est_inflexible est_sec_job  ///
using ${tables}\Table2.txt,  ///
keep(inflexible sec_job  ) ///
b(%9.3f) se(%9.3f) stat(Meany SDy r2_a N, fmt(%9.3f %9.3f %9.3f %9.0f ) /// 
labels("Mean y" "Std Dev y" "R-sq." "N")) /// 
replace starlevels(* 0.10 ** 0.05 *** 0.01) 

***Column 2 
foreach h in  3 {
eststo clear 
estimates clear
qui tab ind_`h', gen(indu)


foreach j in  inflexible sec_job {
reg sd2 `j' indu* if merge_inf==1 & merge_sec==1, cluster(cvrnr)
estimates store est_`j'_`h'

}

esttab  est_inflexible_`h' est_sec_job_`h'   ///
using ${tables}\Table2`h'.txt, keep(inflexible sec_job ) ///
b(%9.3f) se(%9.3f) stat(Meany SDy r2_a N, fmt(%9.3f %9.3f %9.3f %9.0f ) /// 
labels("Mean y" "Std Dev y" "R-sq." "N")) replace starlevels(* 0.10 ** 0.05 *** 0.01) 
drop indu* 

}


*****************************************
***LOWER PART OF THE TABLE***************
*****************************************

****add the share of workers (part-timers; hourly; overtime) and then sd of vacation hours

****share of overtime workers
use  ${data}data_pre_akm_all_pt.dta, clear

gen overtime=timover>0 & timover!=.
bysort cvrnr year: egen tot_over=total(overtime)
bysort cvrnr year: gen tot_norm=_N

gen overtime_share=tot_over/tot_norm

bysort cvrnr year: gen id=_n
keep if id==1
gen high_over=0
forvalues i=2003(1)2011{
sum overtime_share if year==`i',det
replace high_over=1 if overtime_share>r(p75) & year==`i'
}
rename overtime_share  high_overm
collapse high_overm, by( cvrnr year)
rename high_overm   high_over
sort cvrnr year

save ${data}high_over.dta, replace

****share of part-time workers
use  ${data}data_pre_akm_all_pt.dta, clear

tab partime1

bysort cvrnr year: egen tot_part=total(partime1)
bysort cvrnr year: gen tot_norm=_N

gen part_share=tot_part/tot_norm

bysort cvrnr year: gen id=_n
keep if id==1
gen high_part=0
forvalues i=2003(1)2011{
sum part_share if year==`i',det
replace high_part=1 if part_share>r(p75) & year==`i'
}

rename part_share  high_partm
collapse high_partm, by( cvrnr year)
rename high_partm   high_part
sort cvrnr year

save ${data}high_part.dta, replace

****share of hourly workers
use  ${data}data_pre_akm_all_pt.dta, clear


tab aflform
bysort cvrnr year: egen tot_hourly=total(aflform)
bysort cvrnr year: gen tot_norm=_N

gen hourly_share=tot_hourly/tot_norm

bysort cvrnr year: gen id=_n
keep if id==1
gen high_hourly=0
forvalues i=2003(1)2011{
sum hourly_share if year==`i',det
replace high_hourly=1 if hourly_share>r(p75) & year==`i'
}

rename hourly_share  high_hourlym
collapse high_hourlym, by( cvrnr year)
rename high_hourlym   high_hour
sort cvrnr year

save ${data}high_hour.dta, replace


****Create info on vacation hours
use ${data}lonn_add.dta, clear

tostring aflform, replace

append using ${data}lon_add.dta

keep timbet timsh timuge timferie pnr cvrnr year timnorm

gen timef=(timferie==.)

duplicates drop pnr cvrnr year timnorm, force

****Generate cumulative vacation hours within an employer-year 
bys pnr cvrnr year: egen cumtimferie=total(timferie)

duplicates drop pnr cvrnr year, force

keep pnr cvrnr year timferie timef

sort pnr cvrnr year 

save ${temp}otherhours.dta, replace


use ${data}data_pre_akm_all_pt.dta, clear
sort pnr cvrnr year 
save ${temp}pre_akm, replace 
use ${data}data_post_akm_all_hwav1_indov_normpt.dta, clear
sort pnr cvrnr year 
merge  pnr cvrnr year  using ${temp}pre_akm
drop _merge
erase ${temp}pre_akm.dta


****Merge info on vacation hours
sort pnr cvrnr year
merge pnr cvrnr year   using ${temp}otherhours.dta
*Keep only observations for which we have data on vacation time
keep if _merge==3
drop _merge

****Keep the largest group of connected firms
keep if group==1
drop group

gen timtot=timferie

****Define skill groups
gen skill_inddef1=personeffect+xb
forvalues i=10(10)90 {
bys year: egen bound`i'=pctile(skill_inddef1), p(`i')
}
gen skill_def2=.
replace skill_def2=1 if skill_inddef1<=bound10
replace skill_def2=2 if skill_inddef1>bound10 & skill_inddef1<=bound20
replace skill_def2=3 if skill_inddef1>bound20 & skill_inddef1<=bound30
replace skill_def2=4 if skill_inddef1>bound30 & skill_inddef1<=bound40
replace skill_def2=5 if skill_inddef1>bound40 & skill_inddef1<=bound50
replace skill_def2=6 if skill_inddef1>bound50 & skill_inddef1<=bound60
replace skill_def2=7 if skill_inddef1>bound60 & skill_inddef1<=bound70
replace skill_def2=8 if skill_inddef1>bound70 & skill_inddef1<=bound80
replace skill_def2=9 if skill_inddef1>bound80 & skill_inddef1<=bound90
replace skill_def2=10 if skill_inddef1>bound90

****Standard deviation of vacation hours btw skill groups
bysort cvrnr skill_def2 year: egen mean_hours2=mean(timtot)
bysort cvrnr skill_def2 year: keep if _n==1 
bysort cvrnr year: egen sd2=sd(mean_hours2)
gen d=1
bysort cvrnr year: egen sizesg=total(d)
replace sd2=. if sizesg==1
replace sd2=. if timef==1
bysort cvrnr year: keep if _n==1

gen high_vac=0
forvalues i=2003(1)2011{
sum sd2 if year==`i',det
replace high_vac=1 if sd2<r(p25) & year==`i'
}

rename sd2  low_vac

keep low_vac cvrnr year
sort cvrnr year

save ${data}low_vac.dta, replace


****merge share of workers (part-timers; hourly; overtime) and sd of vacation hours
use ${data}finalsample_dario_pt.dta, clear

***Keep only firms with 95% or more of hours reported
keep if fullsize5==1

***Define skill groups
gen skill_inddef1=personeffect+xb
forvalues i=10(10)90 {
bys year: egen bound`i'=pctile(skill_inddef1), p(`i')
}

gen skill_def2=.
replace skill_def2=1 if skill_inddef1<=bound10
replace skill_def2=2 if skill_inddef1>bound10 & skill_inddef1<=bound20
replace skill_def2=3 if skill_inddef1>bound20 & skill_inddef1<=bound30
replace skill_def2=4 if skill_inddef1>bound30 & skill_inddef1<=bound40
replace skill_def2=5 if skill_inddef1>bound40 & skill_inddef1<=bound50
replace skill_def2=6 if skill_inddef1>bound50 & skill_inddef1<=bound60
replace skill_def2=7 if skill_inddef1>bound60 & skill_inddef1<=bound70
replace skill_def2=8 if skill_inddef1>bound70 & skill_inddef1<=bound80
replace skill_def2=9 if skill_inddef1>bound80 & skill_inddef1<=bound90
replace skill_def2=10 if skill_inddef1>bound90

***Standard deviation of hours btw skill groups (i.e. measure of hours constraints)
preserve 
bysort cvrnr skill_def2 year: egen mean_hours2=mean(timtot)
bysort cvrnr skill_def2 year: keep if _n==1 
bysort cvrnr year: egen sd2=sd(mean_hours2)
bysort cvrnr year: keep if _n==1
keep cvrnr year sd2
sort cvrnr year
save ${temp}sd_def2, replace
restore


merge m:1 cvrnr year using ${temp}sd_def2
drop _merge


sort cvrnr year
merge cvrnr year using ${data}high_over
keep if _merge==3
drop _merge


sort  cvrnr year
merge  cvrnr year using ${data}high_part
keep if _merge==3
drop _merge


sort  cvrnr year
merge  cvrnr year using ${data}high_hour
keep if _merge==3
drop _merge


sort  cvrnr year
merge  cvrnr year using ${data}low_vac
keep if _merge==3
drop _merge


***Take average over individuals in the same firm-year

collapse  high_over high_hour low_vac high_part  sd2  ind_3, by(cvrnr year) 

***Column 1
foreach i in  sd2   high_over high_hour low_vac high_part{

egen `i'std=std(`i')
local labelx: variable label `i'
replace `i'=`i'std
label var `i' "`labelx'"

}

foreach j in    high_over high_hour low_vac high_part  {
reg  sd2 `j', cluster(cvrnr)
estimates store est_`j'
}

esttab  est_high_over est_high_part est_high_hour est_low_vac   /// 
using ${tables}\Table_2_add.txt, label ///
b(%9.3f) se(%9.3f) stat(Meany SDy r2_a N, fmt(%9.3f %9.3f %9.3f %9.0f ) /// 
labels("Mean y" "Std Dev y" "R-sq." "N")) /// 
replace starlevels(* 0.10 ** 0.05 *** 0.01) 


***Column 2
foreach h in 3 {
eststo clear 
estimates clear
qui tab ind_`h', gen(indu)

foreach j in high_over high_hour low_vac high_part {
reg sd2 `j' indu*, cluster(cvrnr)
estimates store est_`j'_`h'
}

esttab est_high_over_`h' est_high_part_`h' est_high_hour_`h' est_low_vac_`h'  /// 
using ${tables}\Table_2`h'_add.txt, label ///
b(%9.3f) se(%9.3f) stat(Meany SDy r2_a N, fmt(%9.3f %9.3f %9.3f %9.0f ) /// 
labels("Mean y" "Std Dev y" "R-sq." "N")) /// 
replace starlevels(* 0.10 ** 0.05 *** 0.01) 

drop indu* 
}

log close

