clear
set more off
capture log close

set trace off
clear matrix
set mem 3g

cap log close
log using ${log}Table4.log, replace


use ${data}data_pre_akm_all_pt.dta, clear
sort pnr cvrnr year 
save ${temp}pre_akm, replace 
use ${data}data_post_akm_all_hwav1_indov_normpt.dta, clear
sort pnr cvrnr year 
merge  pnr cvrnr year  using ${temp}pre_akm
erase ${temp}pre_akm.dta

***Keep the largest group of connected firms
keep if group==1
drop group

gen timtot=timnorm+timover

***Define skill groups
gen skill_inddef1=personeffect+xb
forvalues i=10(10)90 {
bys year: egen bound`i'=pctile(skill_inddef1), p(`i')
}
gen skill_def2=.
replace skill_def2=1 if skill_inddef1<=bound10
replace skill_def2=2 if skill_inddef1>bound10 & skill_inddef1<=bound20
replace skill_def2=3 if skill_inddef1>bound20 & skill_inddef1<=bound30
replace skill_def2=4 if skill_inddef1>bound30 & skill_inddef1<=bound40
replace skill_def2=5 if skill_inddef1>bound40 & skill_inddef1<=bound50
replace skill_def2=6 if skill_inddef1>bound50 & skill_inddef1<=bound60
replace skill_def2=7 if skill_inddef1>bound60 & skill_inddef1<=bound70
replace skill_def2=8 if skill_inddef1>bound70 & skill_inddef1<=bound80
replace skill_def2=9 if skill_inddef1>bound80 & skill_inddef1<=bound90
replace skill_def2=10 if skill_inddef1>bound90

***Generate  standard dev within skill groups
bysort cvrnr skill_def2 year: egen sd_within_sk1=sd(timtot)

***Generate standard deviation of hours (no skill groups involved)
bysort cvrnr year: egen std_noskg=sd(timtot)

bysort cvrnr year: keep if _n==1
collapse  std_noskg sd_within_sk1, by(cvrnr)
sort cvrnr
save ${data}std_noskg.dta, replace

use  ${data}dario_part_time_new.dta, clear
sort cvrnr
merge cvrnr using ${data}std_noskg.dta
keep if _merge==3
drop _merge

sort cvrnr
merge cvrnr using ${data}preference
keep if _merge==3
drop _merge

drop if preference==.

***Standardize variables
rename firmeffect_hwav1_part_norm firmeffect_hwav1_norm_firm
rename firmeffectn_hwav1_part_norm  firmeffectn_hwav1_norm_firm
rename sdn_5uw_hwav1_part_norm sdn_5uw_hwav1_norm_firm
rename mad_5uw_hwav1_part_norm  mad_5uw_hwav1_norm_firm 
rename  sgs5_hwav1_part_norm_1  sgs5_hwav1_norm_firm_1 
rename  sgs5_hwav1_part_norm_2  sgs5_hwav1_norm_firm_2
rename  sgs5_hwav1_part_norm_3  sgs5_hwav1_norm_firm_3
rename  sgs5_hwav1_part_norm_4  sgs5_hwav1_norm_firm_4
rename  sgs5_hwav1_part_norm_5  sgs5_hwav1_norm_firm_5
rename  sgs5_hwav1_part_norm_6  sgs5_hwav1_norm_firm_6
rename  sgs5_hwav1_part_norm_7  sgs5_hwav1_norm_firm_7
rename  sgs5_hwav1_part_norm_8  sgs5_hwav1_norm_firm_8
rename  sgs5_hwav1_part_norm_9  sgs5_hwav1_norm_firm_9
rename  sgs5_hwav1_part_norm_10 sgs5_hwav1_norm_firm_10
rename sd_5uw_hwav1_part_norm sd_5uw_hwav1_norm_firm
rename sd_within_sk1 p9010_5uw_hwav1_norm_firm

gen feffect_hwav1_norm_firmnd= firmeffect_hwav1_norm_firm
gen sd_5uw_hwav1_norm_firmnd= sd_5uw_hwav1_norm_firm
gen lhwagend=lhwage


ds hourlyind indfixsam cvrnr ind ind_1 ind_2 ind_3 ind_5 min_ind min_ind2  reg1 reg2 reg3 reg4 reg5 i1 i2 i3 i4 i5 i6   indpeak lhwagend feffect_hwav1_norm_firmnd  sd_5uw_hwav1_norm_firmnd, not

foreach i of var `r(varlist)' {
egen `i'std=std(`i')
local labelx: variable label `i'
replace `i'=`i'std
label var `i' "`labelx'"

}

tab ind_3, gen(ind_3_)

global ability      "avmangability avmedtability avmedbability avbotability"
global cntrl_base  "fansh exp funion female timnorm timnorm2 cap_emp preference"
global  prod        "va_emp vaemp2 vaemp3 tfp"
global reg       "reg1-reg4"
global threedigit "ind_3_*"

***Replicate colum 5 of Table 3 to run the robustness checks on the same sample of firms
reg firmeffect_hwav1_norm_firm sd_5uw_hwav1_norm_firm $cntrl_base $reg  $ability preference $threedigit sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9 sgs5_hwav1_norm_firm_10,  vce(cluster ind_3)

***Keep only firms of column 5 of Table 3
gen samplerobcheck=e(sample)
keep if samplerobcheck==1 

preserve
sort cvrnr
merge cvrnr using ${data}sd_def2_NORM
drop _merge

foreach i of var sd2 firmeffect  {
egen `i'std=std(`i')
local labelx: variable label `i'
replace `i'=`i'std
label var `i' "`labelx'"
}

replace sdn_5uw_hwav1_norm_firm=sd2 
replace   firmeffectn_hwav1_norm_firm=firmeffect 

***Column 1: Standard dev of normal hours only
reg firmeffectn_hwav1_norm_firm sdn_5uw_hwav1_norm_firm $cntrl_base $reg  $ability $threedigit  sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9  sgs5_hwav1_norm_firm_10    ,  vce(cluster ind_3) 
estimates store ss5uw_hwav1_norm_firm_nbi
estadd local fixed0 "YES": ss5uw_hwav1_norm_firm_nbi
estadd local fixed1 "YES": ss5uw_hwav1_norm_firm_nbi
estadd local fixed2 "YES": ss5uw_hwav1_norm_firm_nbi
restore

***Column 2: Exclude firms between 36.5 and at 37.5 weekly hours
reg firmeffect_hwav1_norm_firm sd_5uw_hwav1_norm_firm  $cntrl_base $reg  $ability $threedigit  sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9  sgs5_hwav1_norm_firm_10     if indpeak==0, vce(cluster ind_3)   
estimates store ss5uw_hwav1_norm_firm_h37
estadd local fixed0 "YES": ss5uw_hwav1_norm_firm_h37
estadd local fixed1 "NO": ss5uw_hwav1_norm_firm_h37
estadd local fixed2 "YES": ss5uw_hwav1_norm_firm_h37

***Column 3: within skills
reg firmeffect_hwav1_norm_firm p9010_5uw_hwav1_norm_firm $cntrl_base $reg  $ability $threedigit  sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9 sgs5_hwav1_norm_firm_10  ,  vce(cluster ind_3)
estimates store ss5uw_hwav1_norm_firm_pin3
estadd local fixed0 "YES": ss5uw_hwav1_norm_firm_pin3
estadd local fixed1 "YES": ss5uw_hwav1_norm_firm_pin3
estadd local fixed2 "YES": ss5uw_hwav1_norm_firm_pin3

***Column 4: Simple Std. Dev Across (no skill groups)
reg firmeffect_hwav1_norm_firm std_noskg $cntrl_base $reg  $ability $threedigit  sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9  sgs5_hwav1_norm_firm_10    ,  vce(cluster ind_3)
estimates store ss1uw_hwav1_norm_firm_in3
estadd local fixed0 "YES": ss1uw_hwav1_norm_firm_in3
estadd local fixed1 "YES": ss1uw_hwav1_norm_firm_in3
estadd local fixed2 "YES": ss1uw_hwav1_norm_firm_in3

***Column 6: Median Absolute Deviation
reg firmeffect_hwav1_norm_firm mad_5uw_hwav1_norm_firm $cntrl_base $reg  $ability $threedigit  sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9  sgs5_hwav1_norm_firm_10       ,  vce(cluster ind_3)
estimates store ss5uw_hwav1_norm_firm_min3
estadd local fixed0 "YES": ss5uw_hwav1_norm_firm_min3
estadd local fixed1 "YES": ss5uw_hwav1_norm_firm_min3
estadd local fixed2 "YES": ss5uw_hwav1_norm_firm_min3

****Column 5: exclude part-time workers
use  ${data}finalsample_dario2.dta, clear

gen feffect_hwav1_norm_firmnd=firmeffect_hwav1_norm_firm
gen sd_5uw_hwav1_norm_firmnd= sd_5uw_hwav1_norm_firm
gen lhwagend=lhwage


ds hourlyind indfixsam cvrnr ind ind_1 ind_2 ind_3 ind_5 min_ind min_ind2  reg1 reg2 reg3 reg4 reg5 i1 i2 i3 i4 i5 i6   indpeak lhwagend feffect_hwav1_norm_firmnd  sd_5uw_hwav1_norm_firmnd, not

foreach i of var `r(varlist)' {
egen `i'std=std(`i')
local labelx: variable label `i'
replace `i'=`i'std
label var `i' "`labelx'"

}

sort cvrnr
merge cvrnr using ${data}preference
keep if _merge==3
drop _merge

drop if preference==.

tab ind_3, gen(ind_3_)

reg firmeffect_hwav1_norm_firm sd_5uw_hwav1_norm_firm $cntrl_base $reg  $ability $threedigit sgs5_hwav1_norm_firm_1 sgs5_hwav1_norm_firm_2 sgs5_hwav1_norm_firm_3 sgs5_hwav1_norm_firm_4 ///
sgs5_hwav1_norm_firm_5 sgs5_hwav1_norm_firm_6 sgs5_hwav1_norm_firm_7 sgs5_hwav1_norm_firm_8 sgs5_hwav1_norm_firm_9 sgs5_hwav1_norm_firm_10, vce(cluster ind_3)
estimates store ss5uw_hwav1_norm_firm_in3
estadd local fixed0 "YES": ss5uw_hwav1_norm_firm_in3
estadd local fixed1 "YES": ss5uw_hwav1_norm_firm_in3
estadd local fixed2 "YES": ss5uw_hwav1_norm_firm_in3

*Output Columns 1 to 6 (column 7 is produced in a separate file: leav_out_sdhours_CHK_firmctrl_wagecomp_july22)
esttab ss5uw_hwav1_norm_firm_nbi  ss5uw_hwav1_norm_firm_h37 ss5uw_hwav1_norm_firm_pin3  ss1uw_hwav1_norm_firm_in3 ss5uw_hwav1_norm_firm_in3  ss5uw_hwav1_norm_firm_min3     /// 
 using ${tables}table4.txt, label /// 
b(%9.3f) se(%9.3f) stat(fixed0 fixed1 fixed2  r2_a N, fmt(%9.3f %9.3f %9.3f %9.3f %9.0f) ///
labels("3 digits Sector f.e." "Av. Hours b/w 36.5 and 37.5" "Part-time Workers"  "R-sq" N)) ///
keep(sdn_5uw_hwav1_norm_firm sd_5uw_hwav1_norm_firm std_noskg mad_5uw_hwav1_norm_firm p9010_5uw_hwav1_norm_firm $cntrl_base) /// 
order(sd_5uw_hwav1_norm_firm sdn_5uw_hwav1_norm_firm p9010_5uw_hwav1_norm_firm std_noskg   mad_5uw_hwav1_norm_firm $cntrl_base) ///
replace starlevels(* 0.10 ** 0.05 *** 0.01)
 
log close