clear
set more off
capture log close


log using ${log}Table6.log, replace

use ${data}finalsample_dario_pt.dta, clear

***Keep only firms with 95% or more of hours reported
keep if fullsize5==1

***Gen Occupation for Merge with PIACC
gen DISCO=substr(occu09,1,4)
gen DISCO3=substr(occu09,1,3)
gen DISCO2=substr(occu09,1,3)
sort DISCO

***Merge with PIACC
merge m:1 DISCO using ${data}coop_piacc1b.dta
drop if _merge==2
drop _m

***Take the median value in each firm-year- Replace with mean when median is missing
foreach j in F_Q01b_median F_Q02a_median {
bysort cvrnr year: egen  f`j'=median(`j')
bysort cvrnr year: egen  fa`j'=mean(`j')
replace f`j'=fa`j' if f`j'==.
}
rename fF_Q02a_median timecooperating
rename fF_Q01b_median sharinginfo

***Skill groups
gen skill_inddef1=personeffect+xb
forvalues i=10(10)90 {
bys year: egen bound`i'=pctile(skill_inddef1), p(`i')
}

gen skill_def2=.
replace skill_def2=1 if skill_inddef1<=bound10
replace skill_def2=2 if skill_inddef1>bound10 & skill_inddef1<=bound20
replace skill_def2=3 if skill_inddef1>bound20 & skill_inddef1<=bound30
replace skill_def2=4 if skill_inddef1>bound30 & skill_inddef1<=bound40
replace skill_def2=5 if skill_inddef1>bound40 & skill_inddef1<=bound50
replace skill_def2=6 if skill_inddef1>bound50 & skill_inddef1<=bound60
replace skill_def2=7 if skill_inddef1>bound60 & skill_inddef1<=bound70
replace skill_def2=8 if skill_inddef1>bound70 & skill_inddef1<=bound80
replace skill_def2=9 if skill_inddef1>bound80 & skill_inddef1<=bound90
replace skill_def2=10 if skill_inddef1>bound90

***Hours Constraints
preserve 
bysort cvrnr skill_def2 year: egen mean_hours2=mean(timtot)
bysort cvrnr skill_def2 year: keep if _n==1 
bysort cvrnr year: egen sd2=sd(mean_hours2)
bysort cvrnr year: keep if _n==1
keep cvrnr year sd2
sort cvrnr year
save ${temp}sd_def2, replace
restore
 
merge m:1 cvrnr year using ${temp}sd_def2
drop _merge

***Take average over individuals in the same firm-year
collapse sd2  ind_3   tfp timecooperating sharinginfo  fcoordact negotiat persuasion  perceptiv r9010occ1 r9010occ3  , by(cvrnr year) 


***Column 1
foreach i in sd2  tfp timecooperating sharinginfo  fcoordact negotiat persuasion  perceptiv r9010occ1 r9010occ3{
egen `i'std=std(`i')
local labelx: variable label `i'
replace `i'=`i'std
label var `i' "`labelx'"
}

foreach j in   tfp timecooperating sharinginfo  fcoordact negotiat persuasion  perceptiv r9010occ1 r9010occ3  {
reg  sd2 `j', cluster(cvrnr)
estimates store est_`j'
}

esttab  est_tfp est_timecooperating est_sharinginfo est_fcoordact est_negotiat est_persuasion est_perceptiv  /// 
est_r9010occ1  est_r9010occ3  ///
using ${tables}\Table6.txt, label ///
b(%9.3f) se(%9.3f) stat(Meany SDy r2_a N, fmt(%9.3f %9.3f %9.3f %9.0f ) /// 
labels("Mean y" "Std Dev y" "R-sq." "N")) /// 
replace starlevels(* 0.10 ** 0.05 *** 0.01) 


***Column 2 
foreach h in 3 {
eststo clear 
estimates clear
qui tab ind_`h', gen(indu)
foreach j in tfp fcoordact negotiat persuasion  perceptiv r9010occ1 r9010occ3 timecooperating sharinginfo {
reg sd2 `j' indu*, cluster(cvrnr)
estimates store est_`j'_`h'
}

esttab est_tfp_`h'  est_timecooperating_`h' est_sharinginfo_`h' est_fcoordact_`h' /// 
est_negotiat_`h' est_persuasion_`h' est_perceptiv_`h'  /// 
est_r9010occ1_`h'  est_r9010occ3_`h' ///
using ${tables}\Table6`h'.txt, label ///
b(%9.3f) se(%9.3f) stat(Meany SDy r2_a N, fmt(%9.3f %9.3f %9.3f %9.0f ) /// 
labels("Mean y" "Std Dev y" "R-sq." "N")) /// 
keep(tfp timecooperating sharinginfo fcoordact negotiat persuasion  perceptiv r9010occ1 r9010occ3) ///
replace starlevels(* 0.10 ** 0.05 *** 0.01) 

drop indu* 

}


log close